#include "RL_CANData.hpp"

/*! getCANStruct: Returns the current CANStruct with a given index.

	@param	int index	- index is between 0 .. 52. CAN_CODE can be used to find the specific code
	@returns CANStruct*	- returns 0 if index is not valid
 */
CANStruct* RL_CANData::getCANStruct(int index) {
	if(index >= HIGH_CANBUS_LENGTH || index < 0) return 0;

	return &(highSpeed[index]);
}

/*! getCurrentSpeed: Returns the current speed of the test vehicle as reported on the CAN
 *
 	@returns int average wheel speed
 */
int RL_CANData::getCurrrentSpeed()
{
	int		FLSpeed = 0,
			FRSpeed = 0,
			BLSpeed = 0,
			BRSpeed = 0,
			avgSpeed = 0;

	FLSpeed = (unsigned int) highSpeed[can840].message.fourByteMsg.byte1;
	FLSpeed = FLSpeed << ONE_BYTE;
	FLSpeed = FLSpeed | highSpeed[can840].message.fourByteMsg.byte2;
	FLSpeed = FLSpeed * SPEED_MULTIPLIER; // 0.031415926

	FRSpeed = (unsigned int) highSpeed[can840].message.fourByteMsg.byte3;
	FRSpeed = FRSpeed << ONE_BYTE;
	FRSpeed = FRSpeed | highSpeed[can840].message.fourByteMsg.byte4;
	FRSpeed = FRSpeed * SPEED_MULTIPLIER; // 0.031415926

	BLSpeed = (unsigned int) highSpeed[can840].message.fourByteMsg.byte1;
	BLSpeed = BLSpeed << ONE_BYTE;
	BLSpeed = BLSpeed | highSpeed[can840].message.fourByteMsg.byte2;
	BLSpeed = BLSpeed * SPEED_MULTIPLIER; // 0.031415926

	BRSpeed = (unsigned int) highSpeed[can840].message.fourByteMsg.byte3;
	BRSpeed = BRSpeed << ONE_BYTE;
	BRSpeed = BRSpeed | highSpeed[can840].message.fourByteMsg.byte4;
	BRSpeed = BRSpeed * SPEED_MULTIPLIER; // 0.031415926

	avgSpeed = ((BRSpeed + BLSpeed + FRSpeed +FLSpeed) / 4);

	return avgSpeed;
}

/*! getBrakePedalPosition function: Returns a value between 0-255 to indicate the
 * 									position of the brake pedal according to the messages on the CAN
 * 	@returns int	- brakePosition */
int RL_CANData::getBrakePedalPosition()
{
	int brakePosition = (int) highSpeed[can241].message.fourByteMsg.byte2;
	return brakePosition;
}

/*! getSteeringWheelPosition function : Returns a value between 0-100 to indicate steering wheel position
 * 										negative for turning left and positive for turning right
 *  @ returns int	- steeringPosition*/
int RL_CANData::getSteeringWheelPosition()
{
	int	steeringPosition = 0;
	steeringPosition = (int) highSpeed[can485].message.fourByteMsg.byte2;
	steeringPosition = steeringPosition << ONE_BYTE;
	steeringPosition = steeringPosition | (int) highSpeed[can485].message.fourByteMsg.byte3;

	if(steeringPosition > GOING_LEFT)
	{
		steeringPosition = ~steeringPosition; // flip the bits if the wheel is turning left
		steeringPosition = steeringPosition * 0.11653653; // convert the value to one between 0-100
		return (steeringPosition * -1); // return a negative value if turning left.
	}

	steeringPosition = steeringPosition * 0.11350737; // convert the value to one between 0-100
	return steeringPosition;
}
