#ifndef RL_CANDATA_H
#define RL_CANDATA_H

#include "RL_CANstructs.h"

#define HIGH_CANBUS_LENGTH 52
#define ONE_BYTE 8
#define SPEED_MULTIPLIER 0.031415926
#define GOING_LEFT 60000

/*! \brief CANBus code available on highspeed bus */
enum CAN_CODE {
	can193, /*!< 8 byte message */
	can197, /*!< 8 byte message */
	can201, /*!< 8 byte message */
	can241, /*!< 4 byte message - Brake pedal position */
	can249, /*!< 8 byte message */
	can288, /*!< 5 byte message */
	can296, /*!< 2 byte message */
	can298, /*!< 8 byte message */
	can304, /*!< 5 byte message */
	can308, /*!< 4 byte message */
	can312, /*!< 5 byte message */
	can381, /*!< 8 byte message */
	can383, /*!< 8 byte message */
	can388, /*!< 6 byte message */
	can401, /*!< 8 byte message */
	can409, /*!< 8 byte message */
	can413, /*!< 8 byte message */
	can417, /*!< 7 byte message */
	can451, /*!< 5 byte message */
	can455, /*!< 7 byte message */
	can461, /*!< 5 byte message */
	can481, /*!< 4 byte message */
	can485, /*!< 8 byte message - Steering angle */
	can489, /*!< 8 byte message */
	can497, /*!< 8 byte message */
	can499, /*!< 2 byte message */
	can501, /*!< 8 byte message */
	can707, /*!< 6 byte message */
	can761, /*!< 5 byte message */
	can820, /*!< 2 byte message */
	can840, /*!< 4 byte message - Wheel speed */
	can842, /*!< 4 byte message */
	can961, /*!< 8 byte message */
	can969, /*!< 8 byte message */
	can977, /*!< 8 byte message */
	can1001, /*!< 8 byte message */
	can1005, /*!< 8 byte message */
	can1009, /*!< 6 byte message */
	can1017, /*!< 8 byte message */
	can1217, /*!< 8 byte message */
	can1225, /*!< 4 byte message */
	can1233, /*!< 8 byte message */
	can1249, /*!< 8 byte message */
	can1257, /*!< 2 byte message */
	can1265, /*!< 8 byte message */
	can1280, /*!< 4 byte message */
	can1300, /*!< 8 byte message */
	can1322, /*!< 8 byte message */
	can1905, /*!< 7 byte message */
	can1906, /*!< 7 byte message */
	can1907, /*!< 7 byte message */
	can1919  /*!< 7 byte message */

};

/*! \brief CANBus data class */
class RL_CANData {
public:
	RL_CANData() {};
	~RL_CANData() {};

	CANStruct* getCANStruct(int index = 0);

	int getCurrrentSpeed();
	int getBrakePedalPosition();
	int getSteeringWheelPosition();
protected:
private:
	CANStruct highSpeed[HIGH_CANBUS_LENGTH]; /*!< Array of CANSturct for high speed bus stored */
};

#endif
