/*
* Name: RL_ImageFrame.hpp
* Desc: Main UI header for the ImageFrame Widget. 
*		Used for displaying the frame sequences.
*
* Issue #: 585
*
* Author: Jihyun Cho
*
* Revision History:
* -----------------
*	03/01/2010 ---> Initial Implementation
*	05/10/2010 ---> Fix for reducing jitter on displaying frames
*/

#ifndef RL_IMAGEFRAME_H
#define RL_IMAGEFRAME_H

#include <libglademm/xml.h>
#include <gtkmm.h>
#include <gtkmm/drawingarea.h>
#include <glibmm/refptr.h>
#include <cairomm/surface.h>
#include <iostream>
#include <fstream>
#include <cstring>

/*! \brief Drawing area for the sequential images */
class RL_ImageFrame : public Gtk::DrawingArea
{
	public:
		/* The constructor called from glade. This constructor is needed for the derived widgets*/
		RL_ImageFrame(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
		
		/* The constructor for RL_ImageFrame */
		RL_ImageFrame();
		
		/* The deconstructor for RL_ImageFrame */
		virtual ~RL_ImageFrame();

		/* Initialization procedure for RL_ImageFrame the frames must be initialized. The initialization can be only done once */
		void Initialize(unsigned int width, unsigned int height);

		/* Rotate the frame 180 degrees
		 */
		void SetFlip(bool set);
		
		/* Update the image buffer for the display 
		*/
		bool UpdateBuffer(unsigned char* data);

	protected:
		/* Called by main Gtk Thread */
    	bool ExposeEvent(GdkEventExpose* e);

    	/* Forces the image widget to redraw itself*/
		bool Timeout();

		guint8 *buf;	/*!< Buffer for the new frame*/
		Glib::RefPtr< Gdk::Pixbuf > pixbuf; /*!< Pixbuf object used to create new pixbuf when there is a new buffer to draw */
		Gtk::Container* parent;		/*!< Pointer to the parent widget*/

	private:
		Glib::Mutex imageMutex; /*!< Image frame mutex */

		int imageWidth; /*!< Width of the frame */
		int imageHeight; /*!< Height of the frame */
		int steps; /*!< Number of steps for Pixbuf. Always 3 */
		

		bool isInitialized;	/*!< True if the RL_ImageFrame is initialized */
		bool isFlip; /*!< True if image frame displays in 180 degrees rotation */
		std::list<Glib::RefPtr<Gdk::Pixbuf> > buf_list; /*!< list for storing the Pixbuf objects for display */
		
};

#endif
