/*
* Name: RL_SequenceFileHeader.hpp
* Desc: The file header structure for the stereo image sequence
*
* Issue #: 585
*
* Author: Jihyun Cho
*
* Revision History:
* -----------------
*	03/01/2010 ---> Initial Implementation
*	07/01/2010 ---> Class Added
*/

/* The header file should only be included once */ 
#ifndef SEQUENCEFILEHEADER_H
#define SEQUENCEFILEHEADER_H

#define MAX_BYTE 		1073741824 /*! Maximum file size for recording is 1G */
#define MAX_NUM_CAMERAS	20	/*! Maximum number of cameras */

#define VERSION_0_TYPE "RoadLab_File_Sequence\0"

#include <cstring>

/*! \brief Color format supported for Road Sequence */
typedef enum RL_ColorFormat { 
	INVALID_COLORFORMAT = -1,
	RGB, 			/*! RGB Color format */
	GRAYSCALE, 		/*! Grayscale Color format */
} COLORFORMAT;

/*! \brief Framerate supported for Road Sequence */
typedef enum RL_FPS { 
	INVALID_FPS = -1,
	FPS30, 			/*! Framerate - 30 frames per second */
	FPS15,
	FPS7_5,
	FPS3_75,
} FPS;

/*! \brief File versions. Currently only 1 version of the sequence file is available*/
typedef enum RL_Version {
	INVALID_VERSION = -1,
	VERSION_0
} VERSION;

/*! \brief Road Sequence file header */
typedef struct sequenceHeader {
	char filetype[23];	/*!< Constant File Type Data "RoadLab_File_Sequence" */
	unsigned int width;	/*!< Number of pixels in width */
	unsigned int height; /*!< Number of pixels in height */
	unsigned int numCameras;
	unsigned int serialNumbers[MAX_NUM_CAMERAS];
	COLORFORMAT format; /*!< Color format */
	FPS fps; /*!<Framerate */

	// Initialize the start of file with string "RoadLab_File_Sequence"	
	/*! \brief The file header structure for the stereo image sequence */
} SEQUENCE_HEADER;

class RL_SequenceFileHeader
{
public:
	// Constructor for Writing
	RL_SequenceFileHeader(unsigned int nCam, unsigned int* serials);

	// Constructor for Reading
	RL_SequenceFileHeader();

	virtual ~RL_SequenceFileHeader();

	void SetResolution(int width, int height);
	void SetCameras(unsigned int* serials, unsigned int numOfCameras);
	void SetFPS(FPS fps);
	void SetColor(COLORFORMAT color);

	unsigned int GetNumberOfCameras();
	unsigned int GetWidth();
	unsigned int GetHeight();

	
	VERSION GetVersion();
	void GetSerials(unsigned int* serials);
	FPS GetFPS();
	COLORFORMAT GetColor();


	SEQUENCE_HEADER* GetHeader();
protected:

private:
	SEQUENCE_HEADER seqFileHeader; /*!< File header for the sequence read */
};

#endif
