/*
* Name: RL_SequenceReader.hpp
* Desc: The header file for RL_SequenceReader class.
*		RL_SequenceReader class is used for reading the stereo image sequence.
*
* Issue #: 585
*
* Author: Jihyun Cho
*
* Revision History:
* -----------------
*	03/01/2010 ---> Initial Implementation
*	12/20/2010 ---> restructured and optimized
*/

/* The header file should be included only once */ 
#ifndef RL_SEQUENCEREADER_H
#define RL_SEQUENCEREADER_H

#include <stdio.h>
#include "opencv.h"
#include "RL_SequenceFileHeader.hpp"
#include "RL_GPSData.hpp"
#include "RL_CANData.hpp"

using namespace std;

/*! \brief Input Stream class for reading a Roadlab Sequence */
class RL_SequenceReader {
	public:
		/* The constructor */
		RL_SequenceReader();
		RL_SequenceReader(char* filename);
		
		/* The deconstructor */
		virtual ~RL_SequenceReader();
		
		
		bool SetFile(char* filename);

		/* ReadFrame: read single frame from input stream and store data 
		*/
		bool ReadFrame();

		IplImage* GrabFrame(int i);
		unsigned int GrabSerials(int i);
		unsigned int GetNumberOfFrames();

		int GetFrameWidth();
		int GetFrameHeight();
		int GetNumberOfChannels();

		void GetCANStruct(CANStruct* canInfo, int index);
		RL_GPSData* GetGPSData();

	protected:

	private:
		FILE* pFile; /*!< File structure used for opening the input stream */
		unsigned int dataSize; /*!< Size of data per frame */
		unsigned int canbusSize; /*!< Size of CANBus data per frame */
		unsigned int gpsDataSize; /*!< Size of GPS data per frame */
		unsigned int numberOfCam; /*!< Number of cameras in recorded sequence */

		RL_SequenceFileHeader fileHeader; /*!< File header class for the sequence file */
		RL_GPSData* gpsData; /*!< Data class for gps data */
		RL_CANData* canData; /*!< Data class for CANBus data */

		IplImage** frameImage; /*!< images to display on the RL_ImageFrame widget */

		int* lastCycle; /*!< Firewire cycle time at the recording time */
		int* lastCount; /*!< Firewire count at the recording time */
		unsigned int* serials; /*!< A List of serial numbers of the cameras in the recorded sequence */

		/* OpenFile: opens file, and returns file header
		*/
		bool OpenFile(char* filename);

		/* Close input stream */
		bool CloseFile();
};

#endif
