/*
 * RL_StereoParams.cpp
 *
 *  Created on: Jun 18, 2010
 *      Author: taha
 */

#include "RL_StereoParams.h"

/*! \brief Constructor: Initializes the Stereo parameter object.
 */
RL_StereoParams::RL_StereoParams() {
	matR = cvMat(3, 3, CV_64F, R );
	matT = cvMat(3, 1, CV_64F, T );

	unique = UNIQUE_DEFAULT;
	thresh = THRESH_DEFAULT;
	windowSize = WINDOW_DEFAULT;
	filterSize = PREFILTER_SIZE_DEFAULT;
	filterCap = PREFILTER_CAP_DEFAULT;
	speckleRange = SPECKLE_DEFAULT;
	speckleWindowSize = SPECKLE_WINDOW_DEFAULT;
	disparity = DISPARITY_DEFAULT;
	dpp = DPP_DEFAULT;
	intrinsicLoaded = false;
}

RL_StereoParams::~RL_StereoParams() {
}

/*! \brief WriteToFile: Writes the intrinsics to "ext_<serialnumber1>_<serialnumber1>.xml" file 
	@param unsigned id1 - serial number of the left camera.
	@param unsigned id2 - serial number of the right camera.
	@param const char* path - path of where the extrinsic xml file is going to be.
 */
void RL_StereoParams::WriteToFile(unsigned int id1, unsigned int id2, const char* path)
{
	char filename[200];
	sprintf(filename, "%s/ext_%d_%d.xml", path, id1,id2);
    CvFileStorage* storage = cvOpenFileStorage( filename, 0, CV_STORAGE_WRITE_TEXT);
    cvWrite( storage, "T", &matT);
    cvWrite( storage, "R", &matR);
    cvReleaseFileStorage( &storage );
	leftCam.WriteToFile(id1, path);
	rightCam.WriteToFile(id2, path);
}


/*! \brief ReadFromFile: Reads the intrinsics from "ext_<serialnumber1>_<serialnumber1>.xml" file
	@param unsigned id1 - serial number of the left camera.
	@param unsigned id2 - serial number of the right camera.
	@param const char* path - path of extrinsic xml file.
	@return bool returns true on success, false otherwise.
 */
bool RL_StereoParams::ReadFromFile(unsigned int id1, unsigned int id2, const char* path)
{
	intrinsicLoaded = false;
	if(!leftCam.ReadFromFile(id1, path))
		return false;
	if(!rightCam.ReadFromFile(id2, path))
		return false;
	intrinsicLoaded = true;
	char filename[200];
	sprintf(filename, "%s/ext_%d_%d.xml", path, id1,id2);
    CvFileStorage* storage = cvOpenFileStorage( filename, 0, CV_STORAGE_READ);
    if(storage == NULL)
    	return false;
    CvMat* _T = (CvMat*)cvReadByName(storage,NULL, "T");
    cvCopy(_T, &matT);
    CvMat* _R = (CvMat*)cvReadByName(storage,NULL, "R");
    cvCopy(_R, &matR);

    cvReleaseFileStorage( &storage );

    cvReleaseMat(&_R);
    cvReleaseMat(&_T);

    return true;
}
