/*
 * RL_ViewGUI.hpp
 *
 *  Created on: 2010-06-01
 *      Author: roadlab
 */

#ifndef RL_CALIBRATION_HPP_
#define RL_CALIBRATION_HPP_

#include <iostream>
#include <gtkmm.h>

#include "opencv.h"
#include "RL_ImageFrame.hpp"
#include "RL_StereoProcessor.h"
#include "RL_SequenceReader.hpp"

#define LOGO_IMAGE	"resource/RL_Logo.bmp" /*!< String literal for logo image */

using namespace std;

/*! \brief GUI code for RL_Reader application */
class RL_ViewGUI {
public:
	RL_ViewGUI();
	virtual ~RL_ViewGUI();

protected:
	int filenumber;

	char *filenameBuf;
	Glib::ustring folderPath;

	RL_SequenceReader* inputStream;

	RL_StereoProcessor* stereoProcessor;
	RL_StereoParams stereoParams;

	Gtk::Window* window;

	Glib::Thread* grabLoop;
	Glib::Dispatcher stopEvent;
	Glib::Mutex runMutex, stereoMutex, playMutex, frameMutex;

	RL_ImageFrame* imageFrame[2], *rectified[2], *stereoFrame;
	Gtk::SpinButton* windowSizeSpin, *uniqueSpin, *thresholdSpin,
					*speckleSpin, *speckleWindowSpin, *filterSizeSpin, *filterCapSpin;
	Gtk::HScale *disparityScale;
	Gtk::Button *stopButton, *playButton, *pauseButton;
	Gtk::FileChooserButton *folderChooser;
	Gtk::ComboBox *frameSelector[2];

	Glib::RefPtr<Gnome::Glade::Xml> refBuilder;

	Glib::RefPtr<Gtk::ListStore> frameSelectionModel;
	class ModelColumns : public Gtk::TreeModel::ColumnRecord
	{
	public:

		ModelColumns()
		{ add(mColName); }

		Gtk::TreeModelColumn<Glib::ustring> mColName; /*!< Column description */
	};

	//logo buffer
	guint8 logobuf[320*240*3]; /*!< Buffer for storing the logo image */
	guint8 callogobuf[320*240*3]; /*!< Buffer for storing the logo image */

	int camOnFrame[2];

	unsigned int* serials;

	bool threadRun;
	bool flipStatus;
	bool playing;
	bool stopping;
	bool pausing;
	bool fileOpened;
	bool frameSelectionChanged;

	CvMat cameraMatrix;
	CvMat distCoeffs;

	void SetLogo(RL_ImageFrame* Frame, guint8* log_buf);

//	void Warning(const char* message);

	void SetThreadStatus( bool runStatus);
	bool GetThreadStatus();

	void SetFrameIndex(int i, int n);
	int GetFrameIndex(int i);

	void GrabFrames();
	void UpdateFrames();

	void UpdateStereoParam();
	void SelectFolder();
	void SelectFrame(int i);

	void OnPlay();
	void OnPause();
	void OnStop();

	int DisparityCheck();
	bool OnDestroy(GdkEventAny* event);
	bool OnIdle();

	bool OpenFile(int);

};

#endif /* RL_CALIBRATION_HPP_ */
